Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(66)

Unified Diff: src/compiler/access-builder.h

Issue 2655853010: [TypeFeedbackVector] Combine the literals array and the feedback vector. (Closed)
Patch Set: gyp file Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/compiler/access-builder.h
diff --git a/src/compiler/access-builder.h b/src/compiler/access-builder.h
index 6275f7a8fd00e362b55eb46f2c011381433dd09a..9d23220e82b25f5943a31adfa6b1ec94f129f269 100644
--- a/src/compiler/access-builder.h
+++ b/src/compiler/access-builder.h
@@ -64,8 +64,8 @@ class V8_EXPORT_PRIVATE AccessBuilder final
// Provides access to JSFunction::shared() field.
static FieldAccess ForJSFunctionSharedFunctionInfo();
- // Provides access to JSFunction::literals() field.
- static FieldAccess ForJSFunctionLiterals();
+ // Provides access to JSFunction::feedback_vector() field.
+ static FieldAccess ForJSFunctionFeedbackVector();
// Provides access to JSFunction::code() field.
static FieldAccess ForJSFunctionCodeEntry();

Powered by Google App Engine
This is Rietveld 408576698